==> kubernetes-model-core-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/TolerationFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TolerationFluent<A extends io.fabric8.kubernetes.api.model.TolerationFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getEffect();
  public A withEffect(java.lang.String effect);
  public java.lang.Boolean hasEffect();
  
  /**
   * Method is deprecated. use withEffect instead.
   */
  @java.lang.Deprecated
  public A withNewEffect(java.lang.String arg0);
  public java.lang.String getKey();
  public A withKey(java.lang.String key);
  public java.lang.Boolean hasKey();
  
  /**
   * Method is deprecated. use withKey instead.
   */
  @java.lang.Deprecated
  public A withNewKey(java.lang.String arg0);
  public java.lang.String getOperator();
  public A withOperator(java.lang.String operator);
  public java.lang.Boolean hasOperator();
  
  /**
   * Method is deprecated. use withOperator instead.
   */
  @java.lang.Deprecated
  public A withNewOperator(java.lang.String arg0);
  public java.lang.Long getTolerationSeconds();
  public A withTolerationSeconds(java.lang.Long tolerationSeconds);
  public java.lang.Boolean hasTolerationSeconds();
  public java.lang.String getValue();
  public A withValue(java.lang.String value);
  public java.lang.Boolean hasValue();
  
  /**
   * Method is deprecated. use withValue instead.
   */
  @java.lang.Deprecated
  public A withNewValue(java.lang.String arg0);
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/TolerationFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface TolerationFluent<A extends io.fabric8.kubernetes.api.model.TolerationFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getEffect();
  public A withEffect(java.lang.String effect);
  public java.lang.Boolean hasEffect();
  
  /**
   * Method is deprecated. use withEffect instead.
   */
  @java.lang.Deprecated
  public A withNewEffect(java.lang.String arg0);
  public java.lang.String getKey();
  public A withKey(java.lang.String key);
  public java.lang.Boolean hasKey();
  
  /**
   * Method is deprecated. use withKey instead.
   */
  @java.lang.Deprecated
  public A withNewKey(java.lang.String arg0);
  public java.lang.String getOperator();
  public A withOperator(java.lang.String operator);
  public java.lang.Boolean hasOperator();
  
  /**
   * Method is deprecated. use withOperator instead.
   */
  @java.lang.Deprecated
  public A withNewOperator(java.lang.String arg0);
  public java.lang.Long getTolerationSeconds();
  public A withTolerationSeconds(java.lang.Long tolerationSeconds);
  public java.lang.Boolean hasTolerationSeconds();
  public java.lang.String getValue();
  public A withValue(java.lang.String value);
  public java.lang.Boolean hasValue();
  
  /**
   * Method is deprecated. use withValue instead.
   */
  @java.lang.Deprecated
  public A withNewValue(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
